summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmmemento.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-08-02 19:23:46 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-08-02 19:23:46 +0000
commiteba47f8f0637f451e21348187591e1f1fd58ac74 (patch)
tree448f10b95c656604acc331a3236c1e59bde5c1ad /kpovmodeler/pmmemento.h
parentc7e8736c69373f48b0401319757c742e8607431a (diff)
downloadtdegraphics-eba47f8f0637f451e21348187591e1f1fd58ac74.tar.gz
tdegraphics-eba47f8f0637f451e21348187591e1f1fd58ac74.zip
TQt conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegraphics@1158446 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kpovmodeler/pmmemento.h')
-rw-r--r--kpovmodeler/pmmemento.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/kpovmodeler/pmmemento.h b/kpovmodeler/pmmemento.h
index a3ea9c98..cdbab2d2 100644
--- a/kpovmodeler/pmmemento.h
+++ b/kpovmodeler/pmmemento.h
@@ -27,8 +27,8 @@
#include "pmvariant.h"
#include "pmcommand.h"
#include "pmmetaobject.h"
-#include <qstring.h>
-#include <qptrlist.h>
+#include <tqstring.h>
+#include <tqptrlist.h>
/**
* Class used by @ref PMObjectMemento to store one value.
@@ -65,7 +65,7 @@ public:
/**
* Stores a string
*/
- PMMementoData( PMMetaObject* classType, int vID, const QString& data );
+ PMMementoData( PMMetaObject* classType, int vID, const TQString& data );
/**
* Stores a @ref PMVector
*/
@@ -99,7 +99,7 @@ private:
int m_valueID;
};
-typedef QPtrList<PMMementoData> PMMementoDataList;
+typedef TQPtrList<PMMementoData> PMMementoDataList;
/**
@@ -126,8 +126,8 @@ private:
int m_mode;
};
-typedef QPtrList<PMObjectChange> PMObjectChangeList;
-typedef QPtrListIterator<PMObjectChange> PMObjectChangeListIterator;
+typedef TQPtrList<PMObjectChange> PMObjectChangeList;
+typedef TQPtrListIterator<PMObjectChange> PMObjectChangeListIterator;
/**
* Class that stores the data of povray objects for undo/redo information
@@ -202,10 +202,10 @@ public:
void addData( PMMetaObject* classType, int vID, const PMThreeState data );
/**
* Adds an @ref QString data object. Will be ignored if the memento
* already contains this data
*/
- void addData( PMMetaObject* classType, int vID, const QString& data );
+ void addData( PMMetaObject* classType, int vID, const TQString& data );
/**
* Adds an @ref PMVector data object. Will be ignored if the memento
@@ -228,7 +228,7 @@ public:
/**
* Call this to store an id change
*/
- void addIDChange( PMMetaObject* classType, int vID, const QString& data );
+ void addIDChange( PMMetaObject* classType, int vID, const TQString& data );
/**
* Returns true if the memento contains changed data
@@ -253,7 +253,7 @@ public:
/**
* Returns the old id
*/
- QString oldID( ) const;
+ TQString oldID( ) const;
/**
* If one object is changed, other objects can be changed as well.
*
@@ -289,7 +289,7 @@ private:
/**
* List of changes
*/
- QPtrList<PMObjectChange> m_changedObjects;
+ TQPtrList<PMObjectChange> m_changedObjects;
PMObjectChange* m_pOriginatorChange;
PMObject* m_pOriginator;
};
@@ -298,19 +298,19 @@ private:
/**
* Iterator for memento data
*/
-class PMMementoDataIterator : public QPtrListIterator<PMMementoData>
+class PMMementoDataIterator : public TQPtrListIterator<PMMementoData>
{
public:
PMMementoDataIterator( const PMMemento& m )
- : QPtrListIterator<PMMementoData>( m.m_data )
+ : TQPtrListIterator<PMMementoData>( m.m_data )
{
}
PMMementoDataIterator( const PMMemento* m )
- : QPtrListIterator<PMMementoData>( m->m_data )
+ : TQPtrListIterator<PMMementoData>( m->m_data )
{
}
PMMementoDataIterator( const PMMementoDataList& l )
- : QPtrListIterator<PMMementoData>( l )
+ : TQPtrListIterator<PMMementoData>( l )
{
}
};
@@ -202,10 +202,10 @@ public:
void addData( PMMetaObject* classType, int vID, const PMThreeState data );
/**
- * Adds an @ref QString data object. Will be ignored if the memento
+ * Adds an @ref TQString data object. Will be ignored if the memento
* already contains this data
*/